@@ -1,9 +1,10 @@
 """Print number of PAGes in PDF files.
 
 This simple utility prints file counter, number of pages and filename
-for each given pdf file.
+for each given pdf file. Fields are separated by a '\\t' (horizontal tab)
+character.
 
-Non-pdf files are silently discarded.
+Non-pdf files are silently skipped.
 
 Empty or erroneous pdf files are reported as containing zero pages.
 
@@ -15,9 +16,9 @@ Examples:
 
 """
 
-__version__ = "0.9.1"
+__version__ = "0.9.2"
 
-requires = ["libfunx >=0.9.4", "pdfrw >=0.4"]
+requires = ["pdfrw >=0.4"]
 
 
 
